@@ -3,7 +3,12 @@ from typing import Any
 
 
 class StreamConnection(ABC):
-
+    """
+    Represents a stream connection that once has been successfully established. A connection may be in different states:
+        1. open -> represents an active connection (closed_count=0)
+        2. half_open -> one side of the connection, server or client is closed (closed_count=1)
+        3. closed -> represents closed connection (closed_count=2)
+    """
     @abstractmethod
     def identity(self) -> str:
         """
